@@ -104,29 +104,19 @@ def test_to_pa_datatype():
     assert pa.binary() == to_pa_datatype("bytes")
     assert pa.binary() == to_pa_datatype("binary")
 
-    assert pa.int8() == to_pa_datatype(pd.Int8Dtype)
-    assert pa.int8() == to_pa_datatype(pd.Int8Dtype())
-    assert pa.int16() == to_pa_datatype(pd.Int16Dtype)
-    assert pa.int16() == to_pa_datatype(pd.Int16Dtype())
-    assert pa.int32() == to_pa_datatype(pd.Int32Dtype)
-    assert pa.int32() == to_pa_datatype(pd.Int32Dtype())
-    assert pa.int64() == to_pa_datatype(pd.Int64Dtype)
-    assert pa.int64() == to_pa_datatype(pd.Int64Dtype())
+    assert pa.int8() == to_pa_datatype(pd.Series([1]).astype("Int8").dtype)
+    assert pa.int16() == to_pa_datatype(pd.Series([1]).astype("Int16").dtype)
+    assert pa.int32() == to_pa_datatype(pd.Series([1]).astype("Int32").dtype)
+    assert pa.int64() == to_pa_datatype(pd.Series([1]).astype("Int64").dtype)
 
-    assert pa.uint8() == to_pa_datatype(pd.UInt8Dtype)
-    assert pa.uint8() == to_pa_datatype(pd.UInt8Dtype())
-    assert pa.uint16() == to_pa_datatype(pd.UInt16Dtype)
-    assert pa.uint16() == to_pa_datatype(pd.UInt16Dtype())
-    assert pa.uint32() == to_pa_datatype(pd.UInt32Dtype)
-    assert pa.uint32() == to_pa_datatype(pd.UInt32Dtype())
-    assert pa.uint64() == to_pa_datatype(pd.UInt64Dtype)
-    assert pa.uint64() == to_pa_datatype(pd.UInt64Dtype())
+    assert pa.uint8() == to_pa_datatype(pd.Series([1]).astype("UInt8").dtype)
+    assert pa.uint16() == to_pa_datatype(pd.Series([1]).astype("UInt16").dtype)
+    assert pa.uint32() == to_pa_datatype(pd.Series([1]).astype("UInt32").dtype)
+    assert pa.uint64() == to_pa_datatype(pd.Series([1]).astype("UInt64").dtype)
 
-    assert pa.string() == to_pa_datatype(pd.StringDtype)
-    assert pa.string() == to_pa_datatype(pd.StringDtype())
+    assert pa.string() == to_pa_datatype(pd.Series(["x"]).astype("string").dtype)
 
-    assert pa.bool_() == to_pa_datatype(pd.BooleanDtype)
-    assert pa.bool_() == to_pa_datatype(pd.BooleanDtype())
+    assert pa.bool_() == to_pa_datatype(pd.Series([True]).astype("boolean").dtype)
 
     raises(TypeError, lambda: to_pa_datatype(123))
     raises(TypeError, lambda: to_pa_datatype(None))
